@@ -1,3 +1,4 @@
+import os
 import boto3
 import logging
 import pytz
@@ -122,6 +123,53 @@ class TimestreamReader:
                 result = False
         return result
 
+    @log_it
+    def custom_read(
+        self,
+        sql: str = None,
+        file_path: str = None
+    ) -> List[dict]:
+        '''Executes a Timestream query from a string or file
+        If both `sql` and `file_path` are provided, `file_path` takes precedent
+
+        Parameters
+        ----------
+        sql : str
+            SQL query string
+
+        file_path : str
+            Relative or full path to a file containing the SQL query
+
+        Returns
+        -------
+        records : List[dict]
+        '''
+        assert sql or file_path, 'Must provide a query string or path'
+        if file_path:
+            with open(file_path, 'r') as file_object:
+                sql = file_object.read()
+
+            self._logger.info(f'SQL query read from {file_path}: {sql}')
+
+        resp = self._timestream_read_client.query(
+            QueryString=sql,
+            MaxRows=1000
+        )
+        next_token = resp.get('NextToken')
+        rows = resp.get('Rows') or []
+        columns = resp.get('ColumnInfo') or []
+        while next_token:
+            resp = self._timestream_read_client.query(
+                QueryString=sql,
+                NextToken=next_token,
+                MaxRows=1000
+            )
+            next_token = resp.get('NextToken')
+            rows.extend(resp.get('Rows') or [])
+        self._logger.info(f'Retrieved {len(rows)} records from Timestream')
+        return self._parse_rows(rows, columns)
+
+
     @log_it
     def read(
         self,
